#!/usr/bin/env python
# -*- coding: utf-8 -*-

from .GnuplotPy3 import GnuplotPy3

__all__ = [
            "GnuplotPy3",
          ]

version = "0.0.2"

print("""\

Welcome to GnuplotPy3_{VERSION}""".format( VERSION = version ) )
print()
